@@ -1,10 +1,10 @@
-import collections
 import re
 import sys
+import collections
 
-
-__version__ = '0.3.3'
-
+__author__ = 'Ludovic Gasc (GMLudo)'
+__email__ = 'git@gmludo.eu'
+__version__ = '0.5.0'
 version = __version__ + ' , Python ' + sys.version
 
 
@@ -33,13 +33,6 @@ def _parse_version(ver):
 
 version_info = _parse_version(__version__)
 
-
-from .arbiter import Arbiter
 from .application import Application
-from .request import Request, Response
-from .errors import RESTError, JsonDecodeError, JsonLoadError
-from . import serialize
-
-# make pyflakes happy
-(Arbiter, Application, Request, Response, RESTError, JsonDecodeError, JsonLoadError,
- serialize)
+from .container import Container
+from .worker import Worker
\ No newline at end of file
